-- 图腾材料
Lua_TotemMaterialWindow = class("Lua_TotemMaterialWindow", Lua_Window)
function Lua_TotemMaterialWindow:ctor()
	self:superCall("ctor");
	
	self.windowName = "Lua_TotemMaterialWindow";
	self.skinName = "TotemMaterialWindow_skin";
	self.showBlackMask = true;
end

function Lua_TotemMaterialWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("TOTEM_MATERIAL_SELECT", self, self.onMaterialSelected);
	self.materialList = Array();

	self.btnSure:addClickFuntion(self, self.onSureClick);
end

function Lua_TotemMaterialWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.noneIcon = nil;
	self.noneText = nil;
	if self.materialList then
		self.materialList:clear();
		self.materialList = nil;
	end
	if self.showData then
		self.showData.materialList = nil;
	end
	Lua_MsgUtil.callFunc("TOTEM_MATERIAL_SELECT_COMPLETE");
	self:superCall("dispose");
end

function Lua_TotemMaterialWindow:showWin(param)
	self:superCall("showWin", param);

	local arr = DataCenter.totemData:getSynthesisMaterials(param.star);
	if arr == nil or arr:getSize() <= 0 then
		self:showNone(true);
	else
		self:showNone(false);
		for i = 1, param.materialList:getSize() do
			self.materialList:add(param.materialList[i]);
		end
		self:showList(self.materialList, arr);
	end
	self:onMaterialSelected();
end

function Lua_TotemMaterialWindow:onSureClick(go)
	local arr = self.showData.materialList;
	local len = arr:getSize();
	while len > 0 do
		if self.materialList:indexOf(arr[len]) == -1 then
			arr:remove(len);
		end
		len = len - 1;
	end

	len = self.materialList:getSize();
	for i = 1, len do
		if arr[i] == nil then
			arr:add(self.materialList[i]);
		else
			arr[i] = self.materialList[i];
		end
	end
	self:hide();
end

function Lua_TotemMaterialWindow:showNone(bValue)
	if bValue then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_liaotian_widget_002", 0, 56, 648, 119);
			self.noneIcon:setScale(0.8, 0.8, 1);

			self.noneText = UICreate.createLabel(self.content, nil, 0, 56, 100, 31, 30);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.verticalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("9F928C");
			self.noneText:setLangValue(762002);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end

function Lua_TotemMaterialWindow:showList(customParam, arr)
	if self.itemList == nil then
		local width = Mathf.Ceil(124 * 0.86);
		self.itemList = Lua_DragList.new(self.content, 595, 370, Lua_AxisDefine.Vertical);
		self.itemList:setLocation(0, 56, 0);
		self.itemList:setListCell(Lua_TotemMaterialItem, width, width, 5);
		self.itemList:setCellSpacing(15, 15);
		self.itemList.canLongPress = true;
		self.itemList.longPressLimit = 0.4;
	end
	self.itemList.customParam = customParam;
	self.itemList:setArrayData(arr);
end

function Lua_TotemMaterialWindow:onMaterialSelected(uniqueId)
	local count = DataCenter.totemUtil.composeCount;
	local len = self.materialList:getSize();
	if uniqueId and uniqueId > 0 then
		local index = self.materialList:indexOf(uniqueId);
		if index == -1 then
			if len >= count then
				OperateAlert.showLangValue(762022);
			else
				self.materialList:add(uniqueId);
				len = len + 1;
			end
		else
			self.materialList:remove(index);
			len = len - 1;
		end
	end
	self.numText.text = LanUtil.formateStr(762001, tostring(len), tostring(count));
	if self.itemList then
		self.itemList:updateShowList();
	end
end










Lua_TotemMaterialItem = class("Lua_TotemMaterialItem", Lua_ListCell)
function Lua_TotemMaterialItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_TotemMaterialItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.86, 0.86, 1);
end

function Lua_TotemMaterialItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.customParam = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_TotemMaterialItem:setCustomParam(customParam)
	self.customParam = customParam;
end

function Lua_TotemMaterialItem:setData(data)
	self.data = DataCenter.packData:getItemVoByUnId(data);
	self.itemIcon:setData(self.data);
	self:updateData();
end

function Lua_TotemMaterialItem:updateData()
	if self.customParam == nil or self.customParam:indexOf(self.data.unique_id) == -1 then
		self.itemIcon:setDrawMask(false);
	else
		self.itemIcon:setDrawMask(true);
	end
end

function Lua_TotemMaterialItem:onPressClick(go)
	Lua_MsgUtil.callFunc("TOTEM_MATERIAL_SELECT", self.data.unique_id);
end

function Lua_TotemMaterialItem:onLongPressClick()
	DataCenter.packUtil:showItemInfo(self.data);
end