-- 图腾更换
Lua_TotemReplaceWindow = class("Lua_TotemReplaceWindow", Lua_Window)
function Lua_TotemReplaceWindow:ctor()
	self:superCall("ctor");
	
	self.windowName = "Lua_TotemReplaceWindow";
	self.skinName = "TotemReplaceWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_TotemReplaceWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("TOTEM_REPLACE_SELECT", self, self.onItemSelected);

	self.pathText:addClickFuntion(self, self.onPathClick);
	self.btnRemove:addClickFuntion(self, self.onRemoveClick);

	Lua_WindowUtil.openWin("Lua_TotemItemDetailsWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_TotemReplaceWindow:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.noneIcon = nil;
	self.noneText = nil;
	self:superCall("dispose");
end

function Lua_TotemReplaceWindow:showWin(param)
	self:superCall("showWin", param);
	local part;
	local arr;
	if param.data == nil then
		part = param.part;
		arr = DataCenter.totemData:getTotemArrByPart(part);
		self.noneObject:SetActive(true);
		self.showObject:SetActive(false);
	else
		local vo = param.data;
		part = vo.part;
		arr = DataCenter.totemData:getTotemArrByPart(part, vo.unique_id);

		-- 已装备道具
		self.noneObject:SetActive(false);
		self.showObject:SetActive(true);
		if self.itemIcon == nil then
			self.itemIcon = Lua_ItemIcon.new(self.showObject);
			self.itemIcon:setScale(0.9, 0.9, 1);
			self.itemIcon:setLocation(-230.5, 250.5, 0);
			self.itemIcon:setData(vo);
		end
		
		local colorStr = Lua_ColorDefine.getItemColorStr(vo.color);
		self.nameText.colorStr = Lua_ColorDefine.transColorStr(colorStr);
		self.nameText.text = vo.name;
		self.scoreText.text = LanUtil.formateStr(762003, tostring(vo.score));
	end
	self:showList(arr);
end

function Lua_TotemReplaceWindow:showList(arr)
	if arr == nil or arr:getSize() <= 0 then
		self:showNone(true);
		if self.itemList then
			self.itemList:setEnable(false);
		end
	else
		self:showNone(false);
		if self.itemList == nil then
			self.itemList = Lua_DragList.new(self.content, 630, 590, Lua_AxisDefine.Vertical);
			self.itemList:setLocation(0, -148, 0);
			self.itemList:setListCell(Lua_TotemReplaceItem, 630, 148, 1);
			self.itemList:setCellSpacing(0, 5);
		end
		self.itemList:setEnable(true);
		self.itemList:setArrayData(arr);
	end
end

function Lua_TotemReplaceWindow:showNone(bValue)
	if bValue then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -112, 497, 153);
			self.noneIcon:setScale(0.8, 0.8, 1);

			self.noneText = UICreate.createLabel(self.content, nil, 0, -142.5, 100, 31, 36);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.verticalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
			self.noneText:setLangValue(762007);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end

function Lua_TotemReplaceWindow:onItemSelected(data)
	local arr = Array();
	arr:add(data.unique_id);
	local other_hero_uid = DataCenter.totemData:getHeroUidByTotem(data.unique_id);
	Lua_ProxyManager.getProxy("Lua_TotemProxy"):sWear(self.showData.heroUid, arr, other_hero_uid);
end

function Lua_TotemReplaceWindow:onPathClick(go)
	-- local id = 219 * 1000000 + 2 * 10000 + 1 * 100 + self.showData.part;
	DataCenter.packUtil:openPathWindow(209073001, false);
end

function Lua_TotemReplaceWindow:onRemoveClick(go)
	local itemUid = self.showData.data.unique_id;
	local hero_uid = DataCenter.totemData:getHeroUidByTotem(itemUid);
	local arr = Array();
	arr:add(itemUid);
	Lua_ProxyManager.getProxy("Lua_TotemProxy"):sRemove(hero_uid, arr);
end










Lua_TotemReplaceItem = class("Lua_TotemReplaceItem", Lua_ListCell)
function Lua_TotemReplaceItem:ctor(p)
	self:superCall("ctor", p, "TotemReplaceItem_skin");
end

function Lua_TotemReplaceItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.9, 0.9, 1);
	self.itemIcon:setLocation(-232, 2, 0);
	self.itemIcon:setCanClick(true);

	self.btnFunc:addClickFuntion(self, self.onFuncClick);
end

function Lua_TotemReplaceItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.ownAvatar then
		self.ownAvatar:dispose();
		self.ownAvatar = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_TotemReplaceItem:setData(data)
	local heroUid = DataCenter.totemData:getHeroUidByTotem(data);
	if heroUid == 0 then
		self.data = DataCenter.packData:getItemVoByUnId(data);
		self.btnFunc:setLangValue(762033);
		self.ownObject:SetActive(false);
	else
		self.data = DataCenter.totemData:getTotemItemVo(data);
		self.btnFunc:setLangValue(762035);
		self.ownObject:SetActive(true);
		local heroVo = DataCenter.heroData:getItemByUniqueId(heroUid);
		self.ownText.text = LanUtil.formateStr(762004, heroVo.name);
		self.ownAvatar:setAltas(heroVo.avatar_atlas_1, heroVo.avatar_sprite_1);
	end
	self.itemIcon:setData(self.data);

	local colorStr = Lua_ColorDefine.getItemColorStr(self.data.color);
	self.nameText.colorStr = Lua_ColorDefine.transColorStr(colorStr);
	self.nameText.text = self.data.name;
	self.scoreText.text = LanUtil.formateStr(762003, tostring(self.data.score));
end

function Lua_TotemReplaceItem:onFuncClick(go)
	Lua_MsgUtil.callFunc("TOTEM_REPLACE_SELECT", self.data);
end