-- 图腾合成
Lua_TotemSynthesisWindow = class("Lua_TotemSynthesisWindow", Lua_Window)
function Lua_TotemSynthesisWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_TotemSynthesisWindow";
	self.skinName = "TotemSynthesisWindow_skin";
	self.isFullSizeWin = true;
	self.isSingleShowWin = true;
	self.showWinBg = true;
	self.winBgPath = "/images/hero/xui_hbtt_bg_01.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_TotemSynthesisWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("MONEY_UPDATE", self, self.onMoneyUpdate);
	self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.onPackUpdate);
	self:addLuaEvent("TOTEM_SCREEN_SELECT", self, self.updateSynthesisList);
	self:addLuaEvent("TOTEM_SYNTHESIS_ITEM", self, self.onSynthesisSelected);
	self:addLuaEvent("TOTEM_SYNTHESIS_MATERIAL_ITEM", self, self.onMaterialSelect);
	self:addLuaEvent("TOTEM_MATERIAL_SELECT_COMPLETE", self, self.updateMaterialItems);
	
	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
	self.roleInfoPanel:setRectAnchor(1);

	self.materialItems = Array();
	self.materialList = Array();
	local count = DataCenter.totemUtil.composeCount;
	local item;
	for i = 1, count do
		item = Lua_TotemSynthesisMaterialItem.new(self.content);
		item:setRectAnchor(1);
		item:setLocation(-199 + (i - 1) * 199, -468, 0);
		item:setData(0);
		self.materialItems:add(item);
	end

	self.dragContainer = Lua_DragListContainer.new(self.content, 620, 420 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragContainer:setLocation(0, -215, 0);
	self.dragContainer:setCellSpacing(15, 15);
	self.dragContainer.canLongPress = true;
	self.dragContainer.longPressLimit = 0.4;

	self.bottomBg = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_widget_002", 0, 121, 720, 121);
	self.bottomBg.anchorValue = 7;
	self.bottomBg.pivotValue = 1;

    local data = Array();
    data:add({ textAtlas = "totem_atlas", textNormalSprite = "xui_hbtt_zgnbutton_5_n", textSelectedSprite = "xui_hbtt_zgnbutton_5_p" });

	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.buttonList:setRectAnchor(7);
	self.buttonList:setLocation(301, 53, 0);
	self.buttonList.pivot = -1;
	self.buttonList:setButtonStyle("common_altas_1", "xui_common_zgnbutton_07", "xui_common_zgnbutton_07", 118, 118, 0.01, 1);
	self.buttonList:setButtonLine("common_altas_1", "xui_common_line_001", 2, 114, 0, 0, 1);
	self.buttonList:setButtonItem(118, 118);
	self.buttonList:setClickCallBack(self, self.onButtonClick);
	self.buttonList:setData(data);
	self.buttonList:setSelected(1);

	self:createBackBtn();
	self.screenBtn:addClickFuntion(self, self.onScreenClick);
	self.btnOneAdd:addClickFuntion(self, self.onOneAddClick);
	self.btnSynthesis:addClickFuntion(self, self.onSynthesisClick);

	local list = DataCenter.totemUtil.totemScreen;
	self:updateSynthesisList(list[1]);
	self:updateConsume();

	Lua_WindowUtil.openWin("Lua_TotemItemDetailsWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_TotemSynthesisWindow:dispose()
	if self.roleInfoPanel then
		self.roleInfoPanel:dispose()
		self.roleInfoPanel = nil
	end
	if self.materialItems then
		self.materialItems:dispose();
		self.materialItems = nil;
	end
	if self.dragContainer then
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end
	self.bottomBg = nil;
	if self.synthesisItem then
		self.synthesisItem:dispose();
		self.synthesisItem = nil;
	end
	DataCenter.totemData.synthesisSelectData = nil;
	self:superCall("dispose");
end

function Lua_TotemSynthesisWindow:onScreenResize()
	self:superCall("onScreenResize");
	if self.dragContainer then
		self.dragContainer:setContentRect(620, 420 + self.adaptHeight);
	end
end

function Lua_TotemSynthesisWindow:onButtonClick(index, data)

end

function Lua_TotemSynthesisWindow:onMoneyUpdate(dic)
	local id = DataCenter.totemUtil.composeCost[1][1];
	if dic == nil or dic[id] == nil then
		return;
	end
	self:updateConsume();
end

function Lua_TotemSynthesisWindow:onPackUpdate(dic)
	local data = DataCenter.totemData.synthesisSelectData;
	if data == nil or dic == nil or dic[data.id] == nil then
		return;
	end
	
	self.materialList:clear();
	self:updateMaterialItems();
end

function Lua_TotemSynthesisWindow:updateSynthesisList(data)
	if self.screenData == data then
		return;
	end
	self.screenData = data;
	self.screenText.text = data[2];

	self:onMaterialClear();

	self.dragContainer:clearList();
	local width = Mathf.Ceil(124 * 0.9);
	local arr;
	for i = 2, 6 do
		self.dragContainer:addChildData(i, Lua_TotemSynthesisTitleItem, 620, 15, 1);

		arr = DataCenter.totemUtil:getTotemArrByType(data[1], i);
		self.dragContainer:addChildData(arr, Lua_TotemSynthesisSelectItem, width, width, 5);
	end
	self.dragContainer:updateChildPos();
	self.dragContainer:moveToIndex(1, true);

	if self.synthesisItem then
		self.synthesisItem:setEnable(false);
	end
end

function Lua_TotemSynthesisWindow:onSynthesisSelected(data)
	if DataCenter.totemData.synthesisSelectData == data then
		return;
	end
	self:onMaterialClear();
	DataCenter.totemData.synthesisSelectData = data;
	self.dragContainer:updateShowList();

	if self.synthesisItem == nil then
		self.synthesisItem = Lua_ItemIcon.new(self.content);
		self.synthesisItem:setRectAnchor(1);
		self.synthesisItem:setLocation(0, -238, 0);
	end
	self.synthesisItem:setEnable(true);
	self.synthesisItem:setData(data);
end

function Lua_TotemSynthesisWindow:onMaterialClear()
	DataCenter.totemData.synthesisSelectData = nil;
	self.materialList:clear();
	self:updateMaterialItems();
end

function Lua_TotemSynthesisWindow:onMaterialSelect()
	local data = DataCenter.totemData.synthesisSelectData;
	if data == nil then
		OperateAlert.showLangValue(762021);
		return;
	end
	Lua_WindowUtil.openWin("Lua_TotemMaterialWindow", Lua_WinParam.ACTION_OPEN, { star = data.star, materialList = self.materialList });
end

function Lua_TotemSynthesisWindow:updateMaterialItems()
	for i = 1, self.materialItems:getSize() do
		self.materialItems[i]:setData(self.materialList[i]);
	end
end

function Lua_TotemSynthesisWindow:updateConsume()
	local list = DataCenter.totemUtil.composeCost;
	local config = getConfig("item", list[1][1]);
	self.costIcon:setAltas(config.atlas, config.sprite);
	local haveCount = DataCenter.packData:getItemCountById(list[1][1]);
	if haveCount < list[1][2] then
		haveCount = Lua_ColorDefine.getColorStr(Lua_ColorDefine.RED_STR, numberTrans(haveCount));
	else
		haveCount = numberTrans(haveCount);
	end
	self.costText.text = LanUtil.formateStr(10044, haveCount, numberTrans(list[1][2]));
	self.costText:resetSize();
	local width = 40 + self.costText.width;
	self.costBg:SetDimensions(width, 32);
	width = Mathf.Abs(width - 40) / 2;
	LuaUtil.setObjPos(self.costObject, 154 - width, 231, 0);
end

function Lua_TotemSynthesisWindow:onScreenClick(go)
	local param = { px = 237, py = -64.5, needAdapt = true, list = DataCenter.totemUtil.totemScreen, selected = self.screenData };
	Lua_WindowUtil.openWin("Lua_TotemScreenWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_TotemSynthesisWindow:onOneAddClick(go)
	local data = DataCenter.totemData.synthesisSelectData;
	if data == nil then
		OperateAlert.showLangValue(762021);
		return;
	end

	local count = DataCenter.totemUtil.composeCount;
	local arr = DataCenter.totemData:getSynthesisMaterials(data.star);
	if arr:getSize() < count then
		OperateAlert.showLangValue(762023);
		return;
	end

	self.materialList:clear();
	for i = 1, count do
		self.materialItems[i]:setData(arr[i]);
		self.materialList:add(arr[i]);
	end
end

function Lua_TotemSynthesisWindow:onSynthesisClick(go)
	local data = DataCenter.totemData.synthesisSelectData;
	if data == nil then
		OperateAlert.showLangValue(762021);
		return;
	end

	local list = DataCenter.totemUtil.composeCost;
	local costId = DataCenter.packData:checkConsumeEnough(list);
	if costId == nil then
		if self.materialList:getSize() < DataCenter.totemUtil.composeCount then
			OperateAlert.showLangValue(762023);
		else
			Lua_ProxyManager.getProxy("Lua_TotemProxy"):sSynthesis(data.id, self.materialList)
		end
	else
		DataCenter.packUtil:openPathWindow(costId);
	end
end










Lua_TotemSynthesisMaterialItem = class("Lua_TotemSynthesisMaterialItem", Lua_DisplayObject)
function Lua_TotemSynthesisMaterialItem:ctor(p)
	self:superCall("ctor", p, "TotemSynthesisMaterialItem_skin");
end

function Lua_TotemSynthesisMaterialItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bg:addClickFuntion(self, self.onPressClick);
end

function Lua_TotemSynthesisMaterialItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose");
end

function Lua_TotemSynthesisMaterialItem:setData(data)
	if data and data > 0 then
		if self.itemIcon == nil then
			self.itemIcon = Lua_ItemIcon.new(self.content);
		end
		self.itemIcon:setEnable(true);
		
		data = DataCenter.packData:getItemVoByUnId(data);
		self.itemIcon:setData(data);
	else
		if self.itemIcon then
			self.itemIcon:setEnable(false);
		end
	end
end

function Lua_TotemSynthesisMaterialItem:onPressClick(go)
	Lua_MsgUtil.callFunc("TOTEM_SYNTHESIS_MATERIAL_ITEM", self.data);
end










Lua_TotemSynthesisTitleItem = class("Lua_TotemSynthesisTitleItem", Lua_DragContainerItem)
function Lua_TotemSynthesisTitleItem:ctor(p)
	self:superCall("ctor", p, "TotemSynthesisTitleItem_skin");
end

function Lua_TotemSynthesisTitleItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_TotemSynthesisTitleItem:dispose()
	self:superCall("dispose");
end

function Lua_TotemSynthesisTitleItem:setData(data)
	self.titleText.text = LanUtil.formateStr(762016, tostring(data));
end










Lua_TotemSynthesisSelectItem = class("Lua_TotemSynthesisSelectItem", Lua_DragContainerItem)
function Lua_TotemSynthesisSelectItem:ctor(p)
	self:superCall("ctor", p, "TotemSynthesisSelectItem_skin");
end

function Lua_TotemSynthesisSelectItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setSiblingIndex(0);
	self.itemIcon:setScale(0.9, 0.9, 1);
end

function Lua_TotemSynthesisSelectItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.drawMask = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_TotemSynthesisSelectItem:onPressClick()
	Lua_MsgUtil.callFunc("TOTEM_SYNTHESIS_ITEM", self.data);
end

function Lua_TotemSynthesisSelectItem:onLongPressClick()
	DataCenter.packUtil:showItemInfo(self.data);
end

function Lua_TotemSynthesisSelectItem:setData(data)
	self.data = data;
	self.itemIcon:setData(data);
	self.posText.text = LanUtil.formateStr(762017, tostring(data.part));
	self:updateData();
end

function Lua_TotemSynthesisSelectItem:updateData()
	self:setDrawMask(self.data == DataCenter.totemData.synthesisSelectData);
end

function Lua_TotemSynthesisSelectItem:setDrawMask(bState)
	if bState then
		if self.drawMask == nil then
			self.drawMask = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_label_14", 0, 0, 0, 0);
			self.drawMask:setScale(0.9, 0.9, 1);
		end
		self.drawMask:setEnable(true);
	else
		if self.drawMask then
			self.drawMask:setEnable(false);
		end
	end
end